"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ObjectSet = void 0;
class ObjectSet {
    constructor(iterable) {
        this[Symbol.toStringTag] = 'Set';
        this._values = [];
        if (iterable) {
            for (const item of iterable) {
                this.add(item);
            }
        }
    }
    add(value) {
        if (!this.has(value)) {
            this._values.push(value);
        }
        return this;
    }
    clear() {
        this._values = [];
    }
    entries() {
        return this._values.map(value => [value, value])[Symbol.iterator]();
    }
    forEach(callback, thisArg) {
        this._values.forEach((value, index, array) => {
            callback.call(thisArg, value, value, this);
        }, thisArg);
    }
    keys() {
        return this[Symbol.iterator]();
    }
    get size() {
        return this._values.length;
    }
    values() {
        return this[Symbol.iterator]();
    }
    [Symbol.iterator]() {
        return this._values[Symbol.iterator]();
    }
}
exports.ObjectSet = ObjectSet;
//# sourceMappingURL=object-set.js.map