import { BinaryValue } from './binary-set';
export interface ZeroArgumentsConstructor<T> {
    new (): T;
}
export declare const TypeTags: {
    Any: string;
    Binary: string;
    Boolean: string;
    Collection: string;
    Custom: string;
    Date: string;
    Document: string;
    Hash: string;
    List: string;
    Map: string;
    Null: string;
    Number: string;
    Set: string;
    String: string;
    Tuple: string;
};
export declare type TypeTag = keyof typeof TypeTags;
export interface BaseType<T = any> {
    type: TypeTag;
}
export interface AnyType extends BaseType {
    type: 'Any';
}
export interface BinaryType extends BaseType<BinaryValue> {
    type: 'Binary';
}
export interface BooleanType extends BaseType<boolean> {
    type: 'Boolean';
}
export interface CollectionType<T = {
    [key: string]: any;
}> extends BaseType<Array<T>> {
    type: 'Collection';
    valueConstructor?: ZeroArgumentsConstructor<T>;
    documentConstructorMapping: DocumentConstructorMapping;
}
export interface DocumentConstructorMapping<T = {
    [key: string]: any;
}> {
    attribute: string;
    mapping: {
        [key: string]: ZeroArgumentsConstructor<T>;
    };
}
export interface DateType extends BaseType<string | number | Date> {
    type: 'Date';
}
export interface ZeroArgumentsConstructor<T> {
    new (): T;
}
export interface DocumentType<T = {
    [key: string]: any;
}> extends BaseType<T> {
    type: 'Document';
    members: any;
    valueConstructor?: ZeroArgumentsConstructor<T>;
}
export interface HashType extends BaseType<{
    [key: string]: any;
}> {
    type: 'Hash';
}
export interface ListType<E = any> extends BaseType<Array<E>> {
    type: 'List';
    memberType: SchemaType;
}
export interface MapType<E = any> extends BaseType<Map<string, E>> {
    type: 'Map';
    memberType: SchemaType;
}
export interface NullType extends BaseType<null> {
    type: 'Null';
}
export interface NumberType extends BaseType<number> {
    type: 'Number';
    versionAttribute?: boolean;
}
export interface SetType extends BaseType<Set<any>> {
    type: 'Set';
    memberType: 'String' | 'Number' | 'Binary';
}
export interface StringType extends BaseType<string> {
    type: 'String';
}
export interface TupleType<T extends Array<any> = Array<any>> extends BaseType<T> {
    type: 'Tuple';
    members: Array<SchemaType>;
}
export declare type SchemaType = AnyType | BinaryType | BooleanType | CollectionType | DateType | DocumentType<any> | HashType | ListType | MapType | NullType | NumberType | SetType | StringType | TupleType;
