"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.unmarshallItem = void 0;
const protocols_1 = require("./protocols");
function unmarshallItem(input, valueConstructor) {
    const unmarshalled = new valueConstructor();
    const schema = unmarshalled[protocols_1.DocumentSchema];
    for (const key of Object.keys(schema)) {
        const { attributeName = key } = schema[key];
        if (attributeName in input) {
            unmarshalled[key] = unmarshallValue(schema[key], input[attributeName]);
        }
    }
    return unmarshalled;
}
exports.unmarshallItem = unmarshallItem;
function unmarshallValue(schemaType, input) {
    switch (schemaType.type) {
        case 'String':
            return input;
        case 'Boolean':
            if (input === 1) {
                return true;
            }
            else if (input === 0) {
                return false;
            }
            return input;
        case 'Document':
            return input ? unmarshallItem(input, schemaType.valueConstructor) : undefined;
        case 'Collection':
            return input ? input.map(item => {
                if (schemaType.documentConstructorMapping) {
                    const attributeValue = item[schemaType.documentConstructorMapping.attribute];
                    const valueConstructor = schemaType.documentConstructorMapping.mapping[attributeValue];
                    if (valueConstructor) {
                        return unmarshallItem(item, valueConstructor);
                    }
                }
                return unmarshallItem(item, schemaType.valueConstructor);
            }) : undefined;
    }
    return input;
}
//# sourceMappingURL=unmarshall.js.map